@@ -9,7 +9,7 @@ n <- 1000  # Number of samples
 p <- 10 # Number of covariates
 X <- matrix(rnorm(n * p), nrow = n) # True (latent) variables # Design matrix
 beta <- c(seq(from = 0.1, to = 1, length.out = 5), rep(0, p-5)) # True regression coefficients
-y <- rbinom(n, 1, (1 + exp(-X %*% beta))^(-1)) # Binomially distributed response
+y <- rbinom(n, 1, plogis(X %*% beta)) # Binomially distributed response
 
 fit <- cv_gds(X, y)
 
