@@ -8,7 +8,7 @@ n <- 100
 p <- 50
 X <- matrix(rnorm(n * p), nrow = n)
 sigmaUU <- diag(x = 0.2, nrow = p, ncol = p)
-W <- X + rnorm(n, sd = diag(sigmaUU))
+W <- X + rnorm(n, sd = sqrt(diag(sigmaUU)))
 beta <- c(seq(from = 0.1, to = 1, length.out = 5), rep(0, p-5))
 y <- X %*% beta + rnorm(n, sd = 1)
 set.seed(1, kind = "Mersenne-Twister", normal.kind = "Inversion")
@@ -24,10 +24,10 @@ test_that("gmus returns correct object", {
   expect_s3_class(fit, "gmus")
   expect_equal(fit$family, "gaussian")
   expect_equal(dim(fit$beta), c(50, 26))
-  expect_equal(round(fit$beta[3, 5], 7), 0.5388245)
+  expect_equal(round(fit$beta[3, 5], 7), 0.4646516)
   expect_equal(round(fit$beta[13, 15], 7), 0)
   expect_equal(length(fit$delta), 26)
-  expect_equal(round(fit$lambda, 7), 0.1123004)
+  expect_equal(round(fit$lambda, 7), 0.0672737)
 })
 
 # Next test that it fails when it should
@@ -62,10 +62,10 @@ test_that("mus function works", {
 # Test that the result is as it should
 test_that("gmus returns correct object", {
   expect_equal(dim(fit$beta), c(50, 1))
-  expect_equal(round(fit$beta[3, 1], 7), 0.4289449)
+  expect_equal(round(fit$beta[3, 1], 7), 0.3711348)
   expect_equal(round(fit$beta[13, 1], 7), 0)
   expect_equal(length(fit$delta), 1)
-  expect_equal(round(fit$lambda, 7), 0.1123004)
+  expect_equal(round(fit$lambda, 7), 0.0672737)
 })
 
 # Test that the S3 methods work
@@ -88,7 +88,7 @@ n <- 1000  # Number of samples
 p <- 10 # Number of covariates
 X <- matrix(rnorm(n * p), nrow = n) # True (latent) variables # Design matrix
 sigmaUU <- diag(x = 0.2, nrow = p, ncol = p)
-W <- X + rnorm(n, sd = diag(sigmaUU))
+W <- X + rnorm(n, sd = sqrt(diag(sigmaUU)))
 beta <- c(seq(from = 0.1, to = 1, length.out = 5), rep(0, p-5)) # True regression coefficients
 y <- rbinom(n, 1, (1 + exp(-X %*% beta))^(-1)) # Binomially distributed response
 fit <- gmus(W, y, family = "binomial")
@@ -98,10 +98,10 @@ test_that("gmus returns correct object", {
   expect_s3_class(fit, "gmus")
   expect_equal(fit$family, "binomial")
   expect_equal(dim(fit$beta), c(10, 26))
-  expect_equal(round(fit$beta[3, 5], 7), 0.1819474)
-  expect_equal(round(fit$beta[7, 1], 7), -0.0852176)
+  expect_equal(round(fit$beta[3, 5], 7), 0.0764739)
+  expect_equal(round(fit$beta[7, 1], 7), -0.1807346)
   expect_equal(length(fit$delta), 26)
-  expect_equal(round(fit$lambda, 7), 0.0053673)
+  expect_equal(round(fit$lambda, 7), 0.0031986)
 })
 
 
